@@ -5,7 +5,7 @@ index_import = "from sqlalchemy import Index"
 
 gino_import = "from gino import Gino"
 unique_cons_import = "from sqlalchemy.schema import UniqueConstraint"
-
+enum_import = "from enum import {enums}"
 gino_init = "db = Gino()"
 gino_init_schema = 'db = Gino(schema="{schema}")'
 
@@ -32,13 +32,22 @@ table_args = """
             )
 
 """
-fk_template = """
+fk_constraint_template = """
     {fk_name} = db.ForeignKeyConstraint(
         [{fk_columns}], [{fk_references_columns}])
 """
-
+fk_in_column = ", db.ForeignKey('{ref_table}.{ref_column}')"
 unique_index_template = """
     UniqueConstraint({columns}, name={name})"""
 
 index_template = """
     Index({name}, {columns})"""
+
+schema = """
+    dict(schema="{schema_name}")"""
+
+enum_class = """class {class_name}({type}):"""
+enum_value = """    {name} = {value}"""
+
+on_delete = ', ondelete="{mode}"'
+on_update = ', onupdate="{mode}"'
