@@ -1,6 +1,3 @@
-import datetime
-
-
 types_mapping = {
     "varchar": "str",
     "float": "int",
@@ -26,6 +23,7 @@ types_mapping = {
     "int": "int",
     "serial": "int",
     "bigserial": "int",
+    "uuid": "UUID",
 }
 
 
